#
# spec file for package google-guest-agent
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global provider        github
%global provider_tld    com
%global project         GoogleCloudPlatform
%global repo            guest-agent
%global provider_prefix %{provider}.%{provider_tld}/%{project}/%{repo}
%global import_path     %{provider_prefix}

Name:           google-guest-agent
Version:        20230221.00
Release:        150000.1.34.1
Summary:        Google Cloud Guest Agent
License:        Apache-2.0
Group:          System/Daemons
URL:            https://%{provider_prefix}
Source0:        %{repo}-%{version}.tar.gz
Source1:        vendor.tar.gz
Source2:        rpmlintrc
Patch0:         disable_google_dhclient_script.patch
Patch1:         dont_overwrite_ifcfg.patch
BuildRequires:  golang-packaging
BuildRequires:  golang(API) = 1.18
Requires:       google-guest-configs
Provides:       google-compute-engine-init = %{version}
Obsoletes:      google-compute-engine-init < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%{go_nostrip}
%{go_provides}

%description
Google Cloud Guest Agent

%prep
%setup -q -n %{repo}-%{version}
%setup -q -D -T -a 1 -n %{repo}-%{version}
%patch0 -p1
%patch1 -p1

%build
%goprep %{import_path}
for bin in google_guest_agent google_metadata_script_runner; do
    pushd "$bin"
    CGO_ENABLED=0 go build -ldflags="-s -w -X main.version=%{version}" -mod=vendor
    popd
done

%install
install -d %{buildroot}%{_bindir}
install -p -m 0755 google_guest_agent/google_guest_agent %{buildroot}%{_bindir}/google_guest_agent
install -p -m 0755 google_metadata_script_runner/google_metadata_script_runner %{buildroot}%{_bindir}/google_metadata_script_runner
install -d %{buildroot}/usr/share/google-guest-agent
install -p -m 0644 instance_configs.cfg %{buildroot}/usr/share/google-guest-agent/instance_configs.cfg
install -d %{buildroot}%{_unitdir}
install -p -m 0644 %{name}.service %{buildroot}%{_unitdir}
install -p -m 0644 google-startup-scripts.service %{buildroot}%{_unitdir}
install -p -m 0644 google-shutdown-scripts.service %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sbindir}
for srv_name in %{buildroot}%{_unitdir}/*.service; do rc_name=$(basename -s '.service' $srv_name); ln -s service %{buildroot}%{_sbindir}/rc$rc_name; done

%pre
    if [ -f /usr/lib/systemd/system/google-ip-forwarding-daemon.service ]; then
        systemctl stop --no-block google-ip-forwarding-daemon
        systemctl disable google-ip-forwarding-daemon.service
    fi
    if [ -f /usr/lib/systemd/system/google-network-setup.service ]; then
        systemctl stop --no-block google-network-setup
        systemctl disable google-network-setup.service
    fi
    %service_add_pre google-guest-agent.service google-shutdown-scripts.service google-startup-scripts.service

%preun
    %service_del_preun google-guest-agent.service google-shutdown-scripts.service google-startup-scripts.service

%post
    # Handle enabling of services during an upgrade from the old google-compute-engine-init package
    if [ "$1" = "1" ] && ! [ -e /.buildenv ] && systemctl is-enabled -q google-accounts-daemon.service 2>/dev/null ; then
	mktemp --suffix ".google-accounts-daemon-enabled"
	if systemctl is-active --quiet google-accounts-daemon.service ; then
	    mktemp --suffix ".google-accounts-daemon-active"
	fi
    fi
    if [ "$1" = "1" ] && ! [ -e /.buildenv ] && systemctl is-enabled -q google-startup-scripts.service 2>/dev/null ; then
	mktemp --suffix ".google-startup-scripts"
    fi
    if [ "$1" = "1" ] && ! [ -e /.buildenv ] && systemctl is-enabled -q google-shutdown-scripts.service 2>/dev/null ; then
	mktemp --suffix ".google-shutdown-scripts"
    fi

    %service_add_post google-guest-agent.service google-shutdown-scripts.service google-startup-scripts.service

%posttrans
    if ! [ -e /.buildenv ] && [ -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-accounts-daemon-enabled ] ; then
        systemctl enable google-guest-agent.service
	rm -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-accounts-daemon-enabled
	if [ -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-accounts-daemon-enabled ] ; then
	    systemctl stop google-accounts-daemon.service
	    systemctl start google-guest-agent.service
	    rm -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-accounts-daemon-active
	fi
    fi
    if ! [ -e /.buildenv ] && [ -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-startup-scripts ] ; then
        rm -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-startup-scripts
        systemctl enable google-startup-scripts.service
    fi
    if ! [ -e /.buildenv ] && [ -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-shutdown-scripts ] ; then
	rm -f /tmp/tmp\.[A-Z,a-z,0-9]*\.google-shutdown-scripts
        systemctl enable google-shutdown-scripts.service
    fi

%postun
    %service_del_postun google-guest-agent.service google-shutdown-scripts.service google-startup-scripts.service

%files
%defattr(0644,root,root,0755)
%license LICENSE
%attr(0755,root,root) %{_bindir}/*
%{_datadir}/google-guest-agent
%{_sbindir}/*
%{_unitdir}/*

%changelog
* Mon Feb 27 2023 rjschwei@suse.com
- Bump go API version to 1.18 (bsc#1208723)
  + Address CVE-2021-38297 and CVE-2022-23806
* Mon Feb 27 2023 adrian.glaubitz@suse.com
- Update to version 20230221.00
  * Allow a comment part of a pub ssh key to have an arbitrary format (#198)
    + Split GetUserKey() into two functions: get and validate
    + Correct the name of ValidateUser func as it validates only users
    + Update tests
  * Update OWNERS (#201)
- from version  20230207.00
  * Update OWNERS file (#199)
* Wed Jan 18 2023 adrian.glaubitz@suse.com
- Update to version 20230112.00
  * Updating logging module so cloud logs are flushed prior to exit (#196)
  * Windows: retry adding MDS route (#194)
* Wed Nov 16 2022 adrian.glaubitz@suse.com
- Update to version 20221109.00
  * Validate user key for whitespace chars (#188)
- from version 20221107.00
  * Fix typo with wsfc agent (#189)
- from version 20221104.00
  * Updates to gce-workload-cert-refresh (#186)
- from version 20221025.00
  * Add workload cert refresh to preset (#185)
* Fri Oct 21 2022 adrian.glaubitz@suse.com
- Update to version 20221018.00
  * Write workload cert status file (#184)
- from version 20221017.00
  * Update workload_cert permissions (#180)
* Mon Oct 10 2022 adrian.glaubitz@suse.com
- Update to version 20220927.00
  * Workload certificate refresh (#182)
* Fri Sep 16 2022 adrian.glaubitz@suse.com
- Update to version 20220824.00
  * Workload certs (#177)
- from version 20220823.00
  * add members to OWNERS (#178)
  * Expired key tests (#176)
  * correct expired key handling (#175)
* Mon Aug 15 2022 dmueller@suse.com
- avoid bashism in post-install scripts (bsc#1195391)
* Wed Aug  3 2022 adrian.glaubitz@suse.com
- Update to version 20220713.00 (bsc#1202100, bsc#1202101)
  * try restoring module mode (#172)
  * update for golang 1.16 (#171)
- from version 20220614.00
  * Remove log that can break startup scripts (#170)
- from version 20220603.00
  * repeat fix for arm (#169)
  * no authorized keys on debian (#168)
- from version 20220527.00
  * Add authorized keys command to the Windows agent package. (#167)
  * Support for Windows SSH (#164)
- from version 20220523.00
  * restore double slash metadata url (#166)
- from version 20220520.00
  * Support .exe as an option for scripts and refactor runScript (#165)
* Thu May  5 2022 adrian.glaubitz@suse.com
- Update to version 20220429.00
  * Move some functionality to a utils module (#162)
* Wed Apr 13 2022 adrian.glaubitz@suse.com
- Update to version 20220412.00
  * enable goproxy during build (#163)
- from version 20220321.00
  * enable routes for ipv6 (#160)
* Tue Feb  8 2022 adrian.glaubitz@suse.com
- Update to version 20220204.00 (bsc#1195437, bsc#1195438)
  * remove han from owners (#154)
  * Remove extra slash from metadata URL. (#151)
- from version 20220104.00
  * List IPv6 routes (#150)
- from version 20211228.00
  * add add or remove route integration test, utils (#147)
- from version 20211214.00
  * add malformed ssh key unit test  (#142)
* Thu Nov 18 2021 adrian.glaubitz@suse.com
- Update to version 20211116.00 (bsc#1193257, bsc#1193258)
  * dont duplicate logs (#146)
  * Add WantedBy network dependencies to google-guest-agent service (#136)
  * dont try dhcpv6 when not needed (#145)
  * Integration tests: instance setup (#143)
  * Integration test: test create and remove google user (#128)
  * handle comm errors in script runner (#140)
  * enforce script ordering (#138)
  * enable ipv6 on secondary interfaces (#133)
- from version 20211103.00
  * Integration tests: instance setup (#143)
- from version 20211027.00
  * Integration test: test create and remove google user (#128)
* Fri Oct 22 2021 adrian.glaubitz@suse.com
- Update to version 20211019.00
  * handle comm errors in script runner (#140)
- from version 20211015.00
  * enforce script ordering (#138)
- from version 20211014.00
  * enable ipv6 on secondary interfaces (#133)
- from version 20211013.00
  * dont open ssh tempfile exclusively (#137)
- from version 20211011.00
  * correct linux startup script order (#135)
  * Emit sshable attribute (#123)
- from version 20210908.1
  * restore line (#127)
- from version 20210908.00
  * New integ test (#124)
- from version 20210901.00
  * support enable-oslogin-sk key (#120)
  * match script logging to guest agent (#125)
- from version 20210804.00
  * Debug logging (#122)
- Refresh patches for new version
  * dont_overwrite_ifcfg.patch
* Tue Jul 27 2021 bwiedemann@suse.com
- Build with go1.15 for reproducible build results (boo#1102408)
* Mon Jul 19 2021 adrian.glaubitz@suse.com
- Update to version 20210707.00
  * Use IP address for calling the metadata server. (#116)
- from version 20210629.00
  * use IP for MDS (#115)
* Wed Jun 23 2021 adrian.glaubitz@suse.com
- Update to version 20210603.00
  * systemd-notify in agentInit (#113)
  * dont check status (#112)
- from version 20210524.00
  * more granular service restarts (#111)
- from version 20210414.00
  * (no functional changes)
* Tue May 11 2021 adrian.glaubitz@suse.com
- Update to version 20210414.00 (bsc#1185848, bsc#1185849)
  * start sshd (#106)
  * Add systemd-networkd.service restart dependency. (#104)
  * Update error message for handleHealthCheckRequest. (#105)
* Wed Mar 31 2021 adrian.glaubitz@suse.com
- Update to version 20210223.01 (bsc#1183414, bsc#1183415)
  * add a match block to sshd_config for SAs (#99)
  * add ipv6 forwarded ip support (#101)
  * call restorecon on ssh host keys (#98)
  * Include startup and shutdown in preset (#96)
  * set metadata URL earlier (#94)
- Fix activation logic of systemd services (bsc#1182793)
* Tue Jan 12 2021 adrian.glaubitz@suse.com
- Update to version 20201211.00
  * Require snapshot scripts to live under /etc/google/snapshots (#90)
  * Adding support for Windows user account password lengths
    between 15 and 255 characters. (#91)
  * Adding bkatyl to OWNERS (#92)
* Tue Nov 24 2020 adrian.glaubitz@suse.com
- Update to version 20201102.00 (bsc#1179031, bsc#1179032)
  * Only attempt to connect to snapshot service once (#88)
* Thu Oct 29 2020 adrian.glaubitz@suse.com
- Update to version 20201026.00
  * remove old unused workflow files (#86)
  * fallback to IP for metadata (#82)
  * getPasswd: Check full prefix of line for username (#81)
* Fri Oct 23 2020 jgleissner@suse.com
- dont_overwrite_ifcfg.patch: Do not overwrite existing ifcfg files
  to allow manual configuration and compatibility with
  cloud-netconfig (bsc#1159460, bsc#1178486)
* Thu Oct  1 2020 adrian.glaubitz@suse.com
- Update to version 20200929.00
  * correct varname (#75)
  * don't call dhclient -x on network setup (#77)
  * add instance id dir override (#78)
  * update agent systemd service file (#73)
  * typo, change to noadjfile (#79)
  * add gaohannk to OWNERS
  * remove illfelder from OWNERS
  * Add all license files to packages (#71)
* Tue Aug 25 2020 adrian.glaubitz@suse.com
- Update to version 20200819.00 (bsc#1175740, bsc#1175741)
  * handle oslogin enable/disable cases (#70) (bsc#1175173)
  * add README (#69)
  * Fix metric for addIPForwardEntry (#68)
  * Correctly determine default route index (#67)
  * oslogin: dont add entry to pam.d/su (#66)
  * end group.conf with newline (#64)
  * Add source field in googet spec (#59)
  * Set route to metadata on interface with default route (#47)
  * fix typo in boto.cfg (#62)
- Properly handle enabling of systemd services when upgrading
  from the old google-compute-engine-init package (bsc#1174745)
* Wed Jul 22 2020 adrian.glaubitz@suse.com
- Initial build (bsc#1174304, bsc#1174306, jsc#ECO-2099, jsc#PM-1945)
  + Version 20200630.00
  + Replaces google-compute-engine-init package
